@@ -162,17 +162,11 @@ KDat::KDat()
     _toolbar->insertSeparator();
 
     _toolbar->insertButton( *ImageCache::instance()->getBackup() , 1, SIGNAL( clicked( int ) ), this, SLOT( fileBackup() ) , TRUE, i18n( "Backup" ) );
+    _toolbar->setButtonIconSet( 1, BarIconSet("kdat_backup"));
     _toolbar->insertButton( *ImageCache::instance()->getRestore(), 2, SIGNAL( clicked( int ) ), this, SLOT( fileRestore() ), TRUE, i18n( "Restore" ) );
+    _toolbar->setButtonIconSet( 2, BarIconSet("kdat_restore"));
     _toolbar->insertButton( *ImageCache::instance()->getVerify() , 3, SIGNAL( clicked( int ) ), this, SLOT( fileVerify() ) , TRUE, i18n( "Verify" ) );
-
-    _toolbar->insertSeparator();
-
-    _toolbar->insertButton( BarIcon( "help" ), 4, SIGNAL( clicked( int ) ), this, SLOT( help() )    , TRUE, i18n( "Help" ) );
-
-    _toolbar->insertSeparator();
-
-    _toolbar->insertButton( BarIcon( "exit" ), 5, SIGNAL( clicked( int ) ), this, SLOT( fileQuit() ), TRUE, i18n( "Quit" ) );
-
+    _toolbar->setButtonIconSet( 3, BarIconSet("kdat_verify"));
     addToolBar( _toolbar );
 
     _statusBar = new KStatusBar( this );
