@@ -16,12 +16,12 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-#include <qfiledialog.h>
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qmultilineedit.h>
 
 #include <kapplication.h>
+#include <kfiledialog.h>
 
 #include "LoggerWidget.h"
 #include <klocale.h>
@@ -55,12 +55,12 @@ void LoggerWidget::append( const QString & text )
 
 void LoggerWidget::save()
 {
-    QString file = QFileDialog::getSaveFileName( QString::null, QString::null, this );
+    QString file = KFileDialog::getSaveFileName( QString::null, QString::null, this );
     if ( !file.isNull() ) {
         QFile f( file );
         if ( f.exists() ) {
-            int result = KMessageBox::warningContinueCancel( this, 
-		   i18n( "Log file exists, overwrite?" ), 
+            int result = KMessageBox::warningContinueCancel( this,
+		   i18n( "Log file exists, overwrite?" ),
                    i18n( "KDat: Save Log" ), 
                    i18n("&Overwrite"));
             if (result != KMessageBox::Continue)
