@@ -1,5 +1,4 @@
-/* kpPty.cpp
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 */
@@ -84,6 +83,8 @@ kpPty::kpPty() : QObject()
   eventLoop = FALSE;
   started = FALSE;
   pUnterm = FALSE;
+  
+  codec = QTextCodec::codecForLocale();
 }
 
 
@@ -290,6 +291,7 @@ void kpPty::readLines()
   QString stext;
   while(pty->readln(stext, false, &unterm) >= 0)
   {
+    stext = codec->toUnicode(stext.ascii(), stext.length());
     emit textIn(stext, !unterm);
     //        kdDebug() << "[" << stext << ">\n";
     if (pUnterm) {
